@@ -8,15 +8,13 @@ class spm_unit_benefits(Variable):
     definition_period = YEAR
     unit = USD
 
-    def formula(spm_unit, period, parameters):
-        PERSON_COMPONENTS = [
+    formula = sum_of_variables(
+        [
             "social_security",
             "ssi",
-            "wic",
             "ca_cvrp",  # California Clean Vehicle Rebate Project.
-        ]
-        SPMU_COMPONENTS = [
             "snap",
+            "wic",
             "free_school_meals",
             "reduced_price_school_meals",
             "lifeline",
@@ -24,6 +22,4 @@ class spm_unit_benefits(Variable):
             "ebb",
             # "tanf", # Exclude until defined for California.
         ]
-        person_components = aggr(spm_unit, period, PERSON_COMPONENTS)
-        spmu_components = add(spm_unit, period, SPMU_COMPONENTS)
-        return person_components + spmu_components
+    )
